@@ -38,7 +38,7 @@ def filter_gabella_a(img, wsize, tr1, cartesian=False, radial=False):
 
     Parameters
     ----------
-    img : array_like
+    img : :py:class:`numpy:numpy.ndarray`
         radar image to which the filter is to be applied
     wsize : int
         Size of the window surrounding the central pixel
@@ -51,7 +51,7 @@ def filter_gabella_a(img, wsize, tr1, cartesian=False, radial=False):
 
     Returns
     -------
-    output : array_like
+    output : :py:class:`numpy:numpy.ndarray`
         an array with the same shape as ``img``, containing the
         filter's results.
 
@@ -78,11 +78,11 @@ def filter_gabella_a(img, wsize, tr1, cartesian=False, radial=False):
         for sr in range_shift:
             refr = np.roll(refa, sr, axis=1)
             count += img - refr < tr1
-    count[:, 0:nn] = wsize ** 2
-    count[:, -nn:] = wsize ** 2
+    count[:, 0:nn] = wsize**2
+    count[:, -nn:] = wsize**2
     if cartesian:
-        count[0:nn, :] = wsize ** 2
-        count[-nn:, :] = wsize ** 2
+        count[0:nn, :] = wsize**2
+        count[-nn:, :] = wsize**2
     return count
 
 
@@ -92,13 +92,13 @@ def filter_gabella_b(img, thrs=0.0):
 
     Parameters
     ----------
-    img : array_like
+    img : :py:class:`numpy:numpy.ndarray`
     thrs : float
         Threshold below which the field values will be considered as no rain
 
     Returns
     -------
-    output : array_like
+    output : :py:class:`numpy:numpy.ndarray`
         contains in each pixel the ratio between area and circumference of the
         meteorological echo it is assigned to or 0 for non precipitation
         pixels.
@@ -164,7 +164,7 @@ def filter_gabella(
 
     Parameters
     ----------
-    img : array_like
+    img : :py:class:`numpy:numpy.ndarray`
     wsize : int
         Size of the window surrounding the central pixel
     thrsnorain : float
@@ -177,12 +177,12 @@ def filter_gabella(
     radial : bool
         True to use radial information only in
         :func:`~wradlib.clutter.filter_gabella_a`.
-    cartesian : boolean
+    cartesian : bool
         True if cartesian data are used, polar assumed if False.
 
     Returns
     -------
-    output : array
+    output : :py:class:`numpy:numpy.ndarray`
         boolean array with pixels identified as clutter set to True.
 
     See Also
@@ -227,12 +227,12 @@ def histo_cut(prec_accum):
 
     Parameters
     ----------
-    prec_accum : array_like
+    prec_accum : :py:class:`numpy:numpy.ndarray`
         spatial array containing rain accumulation
 
     Returns
     -------
-    output : array_like
+    output : :py:class:`numpy:numpy.ndarray`
         boolean array with pixels identified as clutter/shadings set to True.
 
     Examples
@@ -418,15 +418,15 @@ def classify_echo_fuzzy(dat, weights=None, trpz=None, thresh=0.5):
     # check data conformity
     assert np.all(np.in1d(dkeys, list(dat.keys()))), (
         "Argument dat of classify_echo_fuzzy must be a dictionary "
-        "with mandatory keywords %r." % (dkeys,)
+        f"with mandatory keywords {*dkeys,}."
     )
     assert np.all(np.in1d(wkeys, list(weights.keys()))), (
         "Argument weights of classify_echo_fuzzy must be a dictionary "
-        "with keywords %r." % (wkeys,)
+        f"with keywords {*wkeys,}."
     )
     assert np.all(np.in1d(tkeys, list(trpz.keys()))), (
         "Argument trpz of classify_echo_fuzzy must be a dictionary "
-        "with keywords %r." % (tkeys,)
+        "with keywords {*tkeys,}."
     )
 
     # copy rho to rho2
@@ -440,10 +440,10 @@ def classify_echo_fuzzy(dat, weights=None, trpz=None, thresh=0.5):
             else:
                 assert dat[key].shape[-2:] == shape[-2:], (
                     "Arrays of the decision variables have inconsistent "
-                    "shapes: %r vs. %r" % (dat[key].shape, shape)
+                    f"shapes: {dat[key].shape} vs. {shape}"
                 )
         else:
-            print("WARNING: Missing decision variable: %s" % key)
+            print(f"WARNING: Missing decision variable: {key}")
 
     # If all dual-pol moments are NaN, can we assume that and echo is
     # non-meteorological?
@@ -463,7 +463,7 @@ def classify_echo_fuzzy(dat, weights=None, trpz=None, thresh=0.5):
             dat[key] = dummy
 
     # membership in meteorological class for each variable
-    qres = dict()
+    qres = {}
     for key in dat.keys():
         if key not in tkeys:
             continue
@@ -477,7 +477,7 @@ def classify_echo_fuzzy(dat, weights=None, trpz=None, thresh=0.5):
 
     # create weight arrays which are zero where the data is NaN
     # This way, each pixel "adapts" to the local data availability
-    wres = dict()
+    wres = {}
     for key in dat.keys():
         if key not in wkeys:
             continue
@@ -524,9 +524,9 @@ def filter_cloudtype(
 
     Parameters
     ----------
-    img : array_like
+    img : :py:class:`numpy:numpy.ndarray`
         radar image to which the filter is to be applied
-    cloud : array_like
+    cloud : :py:class:`numpy:numpy.ndarray`
         image with collocated cloud value from MSG SAFNWC PGE02 product
     thrs : float
         Threshold above which to identify clutter
@@ -541,15 +541,16 @@ def filter_cloudtype(
     smoothing : float
         Size [m] of the smoothing window used to take into account various
         localisation errors (e.g. advection, parallax)
-    grid : string
+    grid : str
         "polar" or "cartesian"
-    scale : float or tuple of 2 floats
+    scale : float or tuple
+        float or tuple of 2 floats
         range [m] scale for polar grid
         x[m] and y[m] scale for cartesian grid
 
     Returns
     -------
-    output : array_like
+    output : :py:class:`numpy:numpy.ndarray`
         a boolean array containing TRUE where clutter has been identified.
 
     """
@@ -561,7 +562,7 @@ def filter_cloudtype(
     if cirrus:
         noprecip = noprecip | (cloud == 14) | (cloud == 18)
     if smoothing is not None:
-        myfilter = getattr(util, "filter_window_%s" % grid)
+        myfilter = getattr(util, f"filter_window_{grid}")
         noprecip = myfilter(noprecip, smoothing, "minimum", scale)
     clutter = noprecip & (img > thrs)
     return clutter
@@ -576,7 +577,7 @@ def filter_window_distance(img, rscale, fsize=1500, tr1=7):
 
     Parameters
     ----------
-    img : array_like
+    img : :py:class:`numpy:numpy.ndarray`
         2d polar data to which the filter is to be applied
     rscale : float
         range [m] scale of the polar grid
@@ -587,7 +588,7 @@ def filter_window_distance(img, rscale, fsize=1500, tr1=7):
 
     Returns
     -------
-    output : array_like
+    output : :py:class:`numpy:numpy.ndarray`
         an array with the same shape as ``img``, containing the
         filter's results.
 
