@@ -95,7 +95,9 @@ def create_azimuth(decode=False, nrays=360):
     zero_index = np.where(stopaz < startaz)
     stopaz[zero_index[0]] += 360
     azimuth_data = (startaz + stopaz) / 2.0
-    da = xr.DataArray(azimuth_data, dims=["azimuth"], attrs=io.xarray.az_attrs)
+    da = xr.DataArray(
+        azimuth_data, dims=["azimuth"], attrs=io.xarray.az_attrs_template.copy()
+    )
     if decode:
         da = xr.decode_cf(xr.Dataset({"arr": da})).arr
     return da
@@ -105,7 +107,9 @@ def create_elevation(i, decode=False, nrays=360):
     startel = create_startelA(i, nrays=nrays)
     stopel = create_stopelA(i, nrays=nrays)
     elevation_data = (startel + stopel) / 2.0
-    da = xr.DataArray(elevation_data, dims=["azimuth"], attrs=io.xarray.el_attrs)
+    da = xr.DataArray(
+        elevation_data, dims=["azimuth"], attrs=io.xarray.el_attrs_template.copy()
+    )
     if decode:
         da = xr.decode_cf(xr.Dataset({"arr": da})).arr
     return da
@@ -495,6 +499,8 @@ def get_measured_volume(file, format, fileobj, **kwargs):
         if engine == "rainbow":
             pytest.importorskip("xmltodict")
             open_ = io.open_rainbow_dataset
+        if engine == "furuno":
+            open_ = io.open_furuno_dataset
         yield open_(radfile, **kwargs)
 
 
@@ -835,6 +841,64 @@ class TestRainbowVolume01(MeasuredDataVolume):
     backend_kwargs = dict(reindex_angle=1.0)
 
 
+@requires_data
+@requires_xarray_backend_api
+class TestFurunoVolume01(MeasuredDataVolume):
+    name = "furuno/2006_20220324_000000_000.scnx.gz"
+    format = "furuno"
+    volumes = 1
+    sweeps = 1
+    moments = [
+        "RR",
+        "DBZH",
+        "VRADH",
+        "ZDR",
+        "KDP",
+        "PHIDP",
+        "RHOHV",
+        "SQIH",
+        "WRADH",
+        "QUAL",
+    ]
+    elevations = [0.5]
+    azimuths = [720]
+    ranges = [936]
+
+    dsdesc = "sweep{}"
+    mdesc = "moment_{}"
+
+    backend_kwargs = dict(reindex_angle=1.0, obsmode=1)
+
+
+@requires_data
+@requires_xarray_backend_api
+class TestFurunoVolume02(MeasuredDataVolume):
+    name = "furuno/0080_20210730_160000_01_02.scn.gz"
+    format = "furuno"
+    volumes = 1
+    sweeps = 1
+    moments = [
+        "RR",
+        "DBZH",
+        "VRADH",
+        "ZDR",
+        "KDP",
+        "PHIDP",
+        "RHOHV",
+        "SQIH",
+        "WRADH",
+        "QUAL",
+    ]
+    elevations = [7.8]
+    azimuths = [1385]
+    ranges = [602]
+
+    dsdesc = "sweep{}"
+    mdesc = "moment_{}"
+
+    backend_kwargs = dict(reindex_angle=1.0, obsmode=1)
+
+
 @requires_xarray_backend_api
 class TestSyntheticOdimVolume01(SyntheticDataVolume):
     name = "base_odim_data_00"
