@@ -174,8 +174,8 @@ class ErrorMetrics:
         if len(obs) != len(est):
             raise ValueError(
                 "WRADLIB: obs and est need to have the "
-                "same length. len(obs)={}, "
-                "len(est)={}".format(len(obs), len(est))
+                f"same length. len(obs)={len(obs)}, "
+                f"len(est)={len(est)}"
             )
         self.est = est
         self.obs = obs
@@ -213,7 +213,7 @@ class ErrorMetrics:
 
     def sse(self):
         """Sum of Squared Errors"""
-        return np.round(np.sum(self.resids ** 2), 2)
+        return np.round(np.sum(self.resids**2), 2)
 
     def mse(self):
         """Mean Squared Error"""
